@@ -1,6 +1,6 @@
 """Database"""
 
-from .model import BaseModel, model, Foreign, Primary, Unique
+from .models import BaseModel, model, Foreign, Primary, Unique, hook, validate
 from .database import Database
 from ._utils import null, Row, Null
 from .column import Column, text, integer, blob, real
@@ -14,7 +14,7 @@ def test_installed():
     return True
 
 
-__version__ = "0.7.2"
+__version__ = "0.7.5"
 __all__ = [
     "Database",
     "Table",
@@ -29,8 +29,11 @@ __all__ = [
     "real",
     "blob",
     "BaseModel",
-    "model",
+    "models",
     "Foreign",
     "Primary",
-    "Unique"
+    "Unique",
+    "model",
+    "hook",
+    "validate"
 ]
